using System.IO;
using System.Text.Json;
using Blazored.Modal;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Seenginx.Services;
using Seenginx.Services.Models;

namespace Seenginx
{
	public class Startup
	{
		public Startup(IConfiguration configuration)
		{
			Configuration = configuration;
		}

		public IConfiguration Configuration { get; }

		public void ConfigureServices(IServiceCollection services)
		{
			services.AddRazorPages()
#if DEBUG
				.AddRazorRuntimeCompilation()
#endif
				;
			services.AddServerSideBlazor();
			services.AddBlazoredModal();

			var settingsJson = File.ReadAllText(Path.Combine(Directory.GetCurrentDirectory(), "Settings", "settings.json"));
			var settings = JsonSerializer.Deserialize<SeenginxSettings>(settingsJson);

			services.AddSingleton(settings);
			services.AddTransient<CommandService>();
			services.AddTransient<IDmesgService, DmesgService>();
			services.AddTransient<INginxService, NginxService>();
			services.AddTransient<ISystemDService, SystemDService>();
		}

		// This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
		public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
		{
			if (env.IsDevelopment())
			{
				app.UseDeveloperExceptionPage();
			}
			else
			{
				app.UseExceptionHandler("/Error");
			}

			app.UseStaticFiles();

			app.UseRouting();

			app.UseAuthentication();

			app.UseEndpoints(endpoints =>
			{
				endpoints.MapBlazorHub();
				endpoints.MapFallbackToPage("/_Host");
			});
		}
	}
}
